function UT = NLSE3D_Fsym(U,V,h,s,a,method,BC,l_h2,a_12,a_6h2,l_a)
syms Bx By Bz Bc Dx Dy Dz Dc L;

%Get size of data cube:
sizeu = size(U);

%Initialize Ut and (temp) Laplacian cubes:
UT  = sym(zeros(sizeu));
LAP = sym(zeros(sizeu));

%Make interier indicies:
yin       = [2:sizeu(1)-1];
xin       = [2:sizeu(2)-1];
zin       = [2:sizeu(3)-1];

%Compute 3D second order CD Laplacian:
LAP(yin,xin,zin) = l_h2*(U(yin+1,xin,zin) + U(yin-1,xin,zin) +...
                         U(yin,xin+1,zin) + U(yin,xin-1,zin) +...
                         U(yin,xin,zin+1) + U(yin,xin,zin-1) -...
                      6.*U(yin,xin,zin));

%Boundary conditions  
LAP(1  ,xin,zin) = l_h2*Dy*U(1,  xin,zin);
LAP(end,xin,zin) = l_h2*Dy*U(end,xin,zin);
LAP(yin,1  ,zin) = l_h2*Dx*U(yin,1  ,zin);
LAP(yin,end,zin) = l_h2*Dx*U(yin,end,zin);
LAP(yin,xin,  1) = l_h2*Dz*U(yin,xin,  1);
LAP(yin,xin,end) = l_h2*Dz*U(yin,xin,end);
    
LAP(1,1,:)      = l_h2*Dc*U(1,1,:);
LAP(1,end,:)    = l_h2*Dc*U(1,end,:);
LAP(end,1,:)    = l_h2*Dc*U(end,1,:);
LAP(end,end,:)  = l_h2*Dc*U(end,end,:);

LAP(:,1,1)      = l_h2*Dc*U(:,1,1);
LAP(:,1,end)    = l_h2*Dc*U(:,1,end);
LAP(:,end,1)    = l_h2*Dc*U(:,end,1);
LAP(:,end,end)  = l_h2*Dc*U(:,end,end);

LAP(1,  :,1)    = l_h2*Dc*U(1,  :,1);
LAP(1,  :,end)  = l_h2*Dc*U(1,  :,end);
LAP(end,:,1)    = l_h2*Dc*U(end,:,1);
LAP(end,:,end)  = l_h2*Dc*U(end,:,end);

    

if(method==11) %Second order CD method:
    UT(yin,xin,zin) = 1i*(a*LAP(yin,xin,zin) + (a/(h^2))*L*U(yin,xin,zin));   
elseif(method==12) %2SHOC
   UT(yin,xin,zin) = 1i*(...
         -a_12*(LAP(yin+1,xin,zin) + LAP(yin,xin+1,zin) + LAP(yin,xin,zin+1) +...
                LAP(yin-1,xin,zin) + LAP(yin,xin-1,zin) + LAP(yin,xin,zin-1) - ...
             10*LAP(yin,xin,zin))  + ...
       a_6h2*(U(yin+1,xin+1,zin) + U(yin,xin+1,zin+1) + U(yin+1,xin,zin+1) +...
              U(yin-1,xin-1,zin) + U(yin,xin-1,zin-1) + U(yin-1,xin,zin-1) +...
              U(yin+1,xin-1,zin) + U(yin,xin+1,zin-1) + U(yin+1,xin,zin-1) +...
              U(yin-1,xin+1,zin) + U(yin,xin-1,zin+1) + U(yin-1,xin,zin+1) -...
           12*U(yin,xin,zin))   + (a/(h^2))*L*U(yin,xin,zin));   
end %Method

%Boundary conditions  
UT(1  ,xin,zin) = l_h2*1i*a*By*U(1,  xin,zin);
UT(end,xin,zin) = l_h2*1i*a*By*U(end,xin,zin);
UT(yin,1  ,zin) = l_h2*1i*a*Bx*U(yin,1  ,zin);
UT(yin,end,zin) = l_h2*1i*a*Bx*U(yin,end,zin);
UT(yin,xin,  1) = l_h2*1i*a*Bz*U(yin,xin,  1);
UT(yin,xin,end) = l_h2*1i*a*Bz*U(yin,xin,end);
    
UT(1,1,:)      = l_h2*1i*a*Bc*U(1,1,:);
UT(1,end,:)    = l_h2*1i*a*Bc*U(1,end,:);
UT(end,1,:)    = l_h2*1i*a*Bc*U(end,1,:);
UT(end,end,:)  = l_h2*1i*a*Bc*U(end,end,:);

UT(:,1,1)      = l_h2*1i*a*Bc*U(:,1,1);
UT(:,1,end)    = l_h2*1i*a*Bc*U(:,1,end);
UT(:,end,1)    = l_h2*1i*a*Bc*U(:,end,1);
UT(:,end,end)  = l_h2*1i*a*Bc*U(:,end,end);

UT(1,  :,1)    = l_h2*1i*a*Bc*U(1,  :,1);
UT(1,  :,end)  = l_h2*1i*a*Bc*U(1,  :,end);
UT(end,:,1)    = l_h2*1i*a*Bc*U(end,:,1);
UT(end,:,end)  = l_h2*1i*a*Bc*U(end,:,end);    
    
    
       
clear LAP;
return;


   %Non-optimized original 2SHOC formultion:
%    UT(yin,xin,zin) = 1i*(a*(...
%          LAP(yin,xin,zin) - (1/12)*(LAP(yin+1,xin,zin) + LAP(yin-1,xin,zin) +...
%                                     LAP(yin,xin+1,zin) + LAP(yin,xin-1,zin) +...
%                                     LAP(yin,xin,zin+1) + LAP(yin,xin,zin-1) -...
%                                     6.*LAP(yin,xin,zin) ...
%                                 - (2/h^2)*(U(yin-1,xin-1,zin) + ... %D
%                                            U(yin-1,xin+1,zin) + ... %F
%                                            U(yin+1,xin-1,zin) + ... %V
%                                            U(yin+1,xin+1,zin) + ... %X
%                                            U(yin,xin-1,zin+1) + ... %J
%                                            U(yin,xin+1,zin+1) + ... %L
%                                            U(yin,xin-1,zin-1) + ... %P
%                                            U(yin,xin+1,zin-1) + ... %R
%                                            U(yin-1,xin,zin+1) + ... %B
%                                            U(yin-1,xin,zin-1) + ... %H
%                                            U(yin+1,xin,zin+1) + ... %T
%                                            U(yin+1,xin,zin-1) - ... %Z
%                                         4*(U(yin,xin-1,zin) + ...  %M
%                                            U(yin,xin+1,zin) + ...  %O
%                                            U(yin-1,xin,zin) + ...  %E
%                                            U(yin,xin,zin+1) + ...  %K
%                                            U(yin,xin,zin-1) + ...  %Q
%                                            U(yin+1,xin,zin)) + 12*U(yin,xin,zin) ) ) ) + ... %W
%     (-V(yin,xin,zin) +   s*U(yin,xin,zin).*conj(U(yin,xin,zin))).*U(yin,xin,zin));   
 
