%Vortex_profile_generator.m
%Test program for finding steady state vortex ring profiles.
%2012 Ronald M Caplan
%Developed with support from the 
%Computational Science Research Center 
%San Diego State University.
%
%Distributed as part of the NLSEmagic software package at:
%http://www.nlsemagic.com

  clear all;  close all;  
  
  %Top left figure:
  maxm  = 5;
  OMv   = 0.15;  
  rmax_desired = 30;  
  
  %Top right figure:
  %maxm  = 1;
  %OMv   = [0.05:0.05:0.5];  
  %rmax_desired  = 20;
    
  
  
  colors = ['b';'g';'r';'m';'k'];
  for OM=OMv
    
  s  = 1;
  a  = 1;  
  h_r = 0.2;     
   
  disp(['Omega:   ',num2str(OM)]);
  disp(['h_r:     ',num2str(h_r)]);
  rmax = rmax_desired + (h_r-mod(rmax_desired,h_r)) ;
  disp(['rmax:    ',num2str(rmax)]);   
  
  rvec  = [0:h_r:rmax]';  
  res_r = length(rvec);
  ri      = [1:res_r]'; 
  
  U = zeros([res_r 1]);
  V = zeros([res_r 1]);
  Usteady = zeros([res_r-2 1]);
  
   
  fprof = figure(1)
  hold on;
  
  mi = 0;
  for m=1:maxm
      mi = mi+1
      
  if(s>0)    
  Finitv  = (sqrt(3*OM/s).*sech(sqrt(3*OM/(2*a))*(rvec-sqrt(2*a*m^2/OM)))); 
  lBC = 0;
  rBC = 0;
  else
  Finitv = real(sqrt(OM/s + a*m^2./(s*rvec.^2)));
  lBC = 0;
  rBC = sqrt(OM/s + a*m^2./(s*max(rvec).^2));     
  end
  Finitv(1)   = lBC;
  Finitv(end) = rBC;
   
  par = [m,OM,a,s,h_r,lBC,rBC];
   maxit         = 40;
   maxitl        = 40;
   etamax        = 0.9;
   lmeth         = 1;
   restart_limit = 20;
   sol_parms     = [maxit,maxitl,etamax,lmeth,restart_limit];
   [Finitv,it_hist,ierr] = nsoli(Finitv,@(Utmp)NLS_STEADY_F(Utmp,par),(1e-12)*[1,1],sol_parms);
 
   ierr
  
  disp(['m:       ',num2str(m)]);     

        
  figure(1)
  plot(rvec,Finitv,['-' colors(mi)],'LineWidth',4);
  xlabel('r');
  ylabel('f(r)')
  set(gca,'FontSize',18);
  axis([0 rmax 0 max(Finitv)+0.1*max(Finitv)]);

  drawnow
  end
  end
  print('-depsc','-r100','-opengl',['vortex_profiles'],['-f',num2str(fprof)]); 
  
 