close all;
clear all;

%Spatial step-size:
rh      = 0.0075;

%Max r value to integrate to (L):
rxz_max = 500;

%NLSE parameters:
a       =  1
s       = -1
OM      = -1
%Sample VR radius for velocity calculation:
d       =  6;

%Generate r grid:
rxz_vec = (0:rh:rxz_max)';

%Charges to compute:
mvec = [1:10];

for mi=1:length(mvec)

m = mvec(mi)

%Asymptotic 2D profile with boundary values:
Finitv = real(sqrt(OM/s + a*m^2./(s*rxz_vec.^2)));
lBC    = 0;
rBC    = sqrt(OM/s + a*m^2./(s*max(rxz_vec).^2));

%Set up nsoli optimization paramaters:
par = [m,OM,a,s,rh,lBC,rBC];
maxit         = 100;
maxitl        = 50;
etamax        = 0.9;
lmeth         = 2;
restart_limit = 50;
sol_parms     = [maxit,maxitl,etamax,lmeth,restart_limit];

%Set boundary condition values:
Finitv(1)   = lBC;
Finitv(end) = rBC;

% f1d1 = figure(1);
% %plot(rxz_vec,(sqrt(OM/s).*tanh(sqrt(abs(OM/(2*a))).*(rxz_vec))).^2,'-.r','LineWidth',3); 
% hold on;
% plot(rxz_vec,Finitv.^2,'--b','LineWidth',3)  

%Optimize profile:
[Finitv,it_hist,ierr] = nsoli(Finitv,@(Utmp)NLS_STEADY_Fnsoli(Utmp,par),1e-10*[1,1],sol_parms);

% fig_prof = figure(1);
% plot(rxz_vec,Finitv.^2,'-k','LineWidth',5);
% %plot(rxz_vec,log(rxz_vec),'-.g','LineWidth',3); 
% hold off;  
% %title(['f(r) profile for OM=',num2str(OM),' and m=',num2str(m)]);
% %legend('Init Guess','GN Sol','Tanh');
% axis([0 8*m 0 1.1]);
% set(gca,'FontSize',18);
% xlabel('r');
% ylabel('f^2(r)');     
% 
% set(fig_prof, 'PaperPositionMode', 'auto'); 
%set(fig_prof,'InvertHardcopy','off');    
%print('-depsc','-r100','-opengl',['fofr_m',num2str(m),'_OM',num2str(OM)],['-f',num2str(fig_prof)]); 

% f1d2 = figure(2);
% plot(rxz_vec,NLS_STEADY_Fnsoli(Finitv,par))
% title('RHS Residuals for f(r)');         

format long;

%Vortex core radius:
rc = sqrt(-a/OM).*mvec;

%Compute dfdr:
df          = zeros(size(Finitv));
df(3:end-2) = ( -Finitv(5:end) + 8*Finitv(4:end-1) - 8*Finitv(2:end-3) + Finitv(1:end-4))./(12*rh);
df(2)       = (Finitv(3)   - Finitv(1))./(2*rh);
df(end-2)   = (Finitv(end) - Finitv(end-2))./(2*rh);
df(1)       = (-Finitv(3) + 4*Finitv(2) - 3*Finitv(1))./(2*rh);
df(end)     = (-Finitv(end-2) + 4*Finitv(end-1) - 3*Finitv(end))./(2*rh);

Li = length(rxz_vec);
L  = rxz_vec(end);

%Compute energy integrals:
s1 = a*m^2*trapz(rxz_vec(2:Li),(Finitv(2:Li).^2)./(rxz_vec(2:Li)))
s2 = a*trapz(rxz_vec(1:Li),rxz_vec(1:Li).*df(1:Li).^2)
s3 = -(s/2)*trapz(rxz_vec(1:Li),(OM/s - Finitv(1:Li).^2).^2.*rxz_vec(1:Li))
s1conv = -a*m^2*2*trapz(rxz_vec(2:Li),log(rxz_vec(2:Li)).*Finitv(2:Li).*df(2:Li))
%s1test = a*m^2*(OM/s)*log(L)-stest

%L0 only .3808 when rc defined as healing length.  
%Any other rc yields diff L0 but same vel!

%Compute L0 using both forms of convergent integrals:
L0orig(mi) = (s1 + s2 + s3  - ((a*m^2*OM)/s)*log(L/rc(mi)))./((OM*a*m^2)/s)
L0new(mi)  = (s1conv + s2 + s3 + (a*m^2*OM/s)*log(rc(mi)))/((OM*a*m^2)/s)

L0orig(mi)-1
L0new(mi)-1

%compute sample velocity values:
v(mi)    = ((a*m)/d)*(log((8*d)/(m*sqrt(a/-OM))) + L0orig(mi) - 1)
vnew(mi) = ((a*m)/d)*(log((8*d)/(m*sqrt(a/-OM))) + L0new(mi)  - 1)

end

%Display L0 values:
L0orig'
L0new'


figl0 = figure(2);
mvec2 = [1:0.01:10];
plot(mvec,L0new,'sb','LineWidth',5);
hold on;
plot((mvec),(L0orig),'ok','LineWidth',5);
plot(mvec2,L0orig(1)./(mvec2.^(1.6)),'--r','LineWidth',3);
%plot(mvec,L0new(1)./(mvec.^(1.5)),'-r','LineWidth',3);
hold off;
axis([1 max(mvec) min(L0orig(:)) max(L0orig(:))]);
set(gca,'FontSize',18);
xlabel('m','FontSize',18);
ylabel('L_0(m)','FontSize',18);

set(figl0, 'PaperPositionMode', 'auto'); 
set(figl0,'InvertHardcopy','on');    
print('-depsc','-r100','-opengl','L0m1to10',['-f',num2str(figl0)]); 
print('-djpeg','-r100','-opengl','L0m1to10',['-f',num2str(figl0)]);

figl0err=figure(3);
plot((mvec),100*(L0orig(1)./(mvec.^(1.6)) - L0orig)./L0orig,'ok','LineWidth',5);
axis([1 max(mvec) -10 0]);
set(gca,'FontSize',18);
xlabel('m','FontSize',18);
ylabel('%-difference L_0(m) vs L_0(1)/m^1^.^6','FontSize',18);
set(figl0err, 'PaperPositionMode', 'auto'); 
set(figl0err,'InvertHardcopy','on');    
print('-depsc','-r100','-opengl','L0m1to10ERR',['-f',num2str(figl0err)]); 
print('-djpeg','-r100','-opengl','L0m1to10ERR',['-f',num2str(figl0err)]);

